from setuptools import setup

setup(name='test_ira1',
      version='0.0',
      description='calculator',
      packsges=['test_ira1'],
      author='ikkyk',
      author_email='klara.vysotskaya@yandex.ru')
